@@ -102,7 +102,7 @@ class Menu(BaseModel):
 
 class MenuConfig(ObjectDict):
 
-    def __init__(self, von='', menu_alias='', url='', is_log=0, is_show=1, name='', app_name='', *args, **kwargs):
+    def __init__(self, von, menu_alias='', url='', is_log=0, is_show=1, name='', app_name='', *args, **kwargs):
         self.von = str(von)
         self.parent_id = '0' if self.von.count('.') == 0 else self.von.split('.', 2)[0]
         self.alias = menu_alias
