@@ -13,9 +13,10 @@ from django.forms import ModelForm
 from mako.lookup import TemplateLookup
 
 from framework.filters import MyFilterBackend
-from framework.models import BaseModel
+from framework.models import BaseModel, BaseModelMixin
 from framework.route import reverse_view
 from ...utils import mkdirs, ObjectDict
+from django.conf import settings
 
 
 class ModelTemplateCreater(object):
@@ -29,6 +30,7 @@ class ModelTemplateCreater(object):
         self.params['model'] = self.model
         self.params['model_name'] = self.model_name
         self.params['model_lower_name'] = self.model_lower_name
+        self.params['app_verbose_name'] = apps.app_configs.get(self.app_name).verbose_name
         self.options = options
         self.tpl_dir = options.get('tpl_dir') or 'curd_tpl'
 
@@ -36,12 +38,15 @@ class ModelTemplateCreater(object):
         return apps.app_configs.get(self.app_name).path
 
     def get_app_tempalte_path(self):
-        return os.path.join(self.get_app_path(),'jinja2_templates')
+        return os.path.join(self.get_app_path(), 'jinja2_templates')
+
+
 
     @property
     def template_dir(self):
 
-        code_tpl_dir = os.path.abspath(os.path.join(os.path.abspath(__file__), '..', '..', '..', 'code_tpl', self.tpl_dir))
+        code_tpl_dir = os.path.abspath(
+            os.path.join(os.path.abspath(__file__), '..', '..', '..', 'code_tpl', self.tpl_dir))
         print(code_tpl_dir)
         return code_tpl_dir
 
@@ -61,7 +66,25 @@ class ModelTemplateCreater(object):
         if os.path.isfile(single_view_file):
             target_file = single_view_file
         else:
-            target_file = os.path.join(self.get_app_path(), 'views', '%s.py' % self.model_lower_name)
+            target_file = os.path.join(self.get_app_path(), settings.VIEWS_DIR, '%s.py' % self.model_lower_name)
+        self._create_base_file(template_file, target_file)
+
+    def create_model_services_file(self):
+        template_file = 'services.py.tpl'
+        single_service_file = os.path.join(self.get_app_path(), 'services.py')
+        if os.path.isfile(single_service_file):
+            target_file = single_service_file
+        else:
+            target_file = os.path.join(self.get_app_path(), 'services', '%s.py' % self.model_lower_name)
+        self._create_base_file(template_file, target_file)
+
+    def create_model_serializer_file(self):
+        template_file = 'serializer.py.tpl'
+        single_serializer_file = os.path.join(self.get_app_path(), 'serializer.py')
+        if os.path.isfile(single_serializer_file):
+            target_file = single_serializer_file
+        else:
+            target_file = os.path.join(self.get_app_path(), 'serializer', '%s.py' % self.model_lower_name)
         self._create_base_file(template_file, target_file)
 
     def create_files(self):
@@ -149,6 +172,14 @@ class Command(BaseCommand):
 
         model_class: BaseModel = getattr(models, model_name)
 
+        if not issubclass(model_class, BaseModelMixin):
+            # raise Exception('不是继承于 BaseModel' )
+            model_class._meta.abstract = True
+            model_class = type(
+                    model_class.__name__,
+                    (model_class, BaseModelMixin),
+                    {'__module__': model_class.__module__, '__doc__': model_class.__name__}
+            )
         if not model_class:
             self.stderr.write('%s 模型载入失败' % model_name)
             return
@@ -196,9 +227,9 @@ class Command(BaseCommand):
         parmas['model_form'] = model_form
 
         parmas['model_many_to_many'] = model_class._meta.many_to_many
-        parmas['model_foreigns'] = [f for f in model_class.get_fields() if isinstance(f, ForeignKey)]
-        parmas['model_choices_fields'] = [f for f in model_class.get_fields() if f.choices]
-        parmas['model_desc'] = model_class.__doc__.split('\n')[0] or model_name
+        parmas['model_foreigns'] = [f for f in _fields if isinstance(f, ForeignKey)]
+        parmas['model_choices_fields'] = [f for f in _fields if f.choices]
+        parmas['model_desc'] = model_class.__doc__.strip().split('\n')[0] or model_name
 
         parmas['fields_name_list'] = [f.name for f in fields]
         parmas['all_fields_name_list'] = parmas['fields_name_list'] + ['%s_alias' % f.name for f in
